<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+75"/>
        <source>Shape Tools</source>
        <translation>Nástroje Tvaru</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation>Zobraziť nástroje tvaru</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation>&amp;Tvar</translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation>Vytvoriť krivku</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fill</source>
        <translation>Výplň</translation>
    </message>
</context>
</TS>
